@@ -10,14 +10,13 @@ import unittest
 class TestChroot(TrioTestCase):
     async def asyncSetUp(self) -> None:
         self.tmpdir = await mkdtemp(local_thread)
-        self.path = self.tmpdir.path
         self.thr = await local_thread.clone(CLONE.NEWUSER|CLONE.NEWNS)
 
     async def asyncTearDown(self) -> None:
         await self.tmpdir.cleanup()
 
     async def test_basic(self) -> None:
-        await self.thr.mkdir(self.path/"proc")
-        await self.thr.mount("/proc", self.path/"proc", "", MS.BIND, "")
-        await self.thr.task.chroot(await self.thr.ptr(self.path))
+        await self.thr.mkdir(self.tmpdir/"proc")
+        await self.thr.mount("/proc", self.tmpdir/"proc", "", MS.BIND, "")
+        await self.thr.task.chroot(await self.thr.ptr(self.tmpdir))
         await self.thr.task.open(await self.thr.ptr("/proc/self"), O.RDONLY)
